#include "timer0.h"


	ISR(TIM0_OVF_vect)
	{
	}

	ISR(TIM0_COMPA_vect)
	{
	}

	ISR(TIM0_COMPB_vect)
	{
	}

void timer_init()
	{
	/***************************/
	/* Timer0/Counter Register */
	/***************************/

	// TCCR0A = 0bx000.0000; #7 COM0A1 Compare Match Output A Mode
	// TCCR0A = 0b0x00.0000; #6 COM0A0 Compare Match Output A Mode
	// TCCR0A = 0b00x0.0000; #5 COM0B1 Compare Match Output B Mode
	// TCCR0A = 0b000x.0000; #4 COM0B0 Compare Match Output B Mode
	// TCCR0A = 0b0000.x000; #3 xx
	// TCCR0A = 0b0000.0x00; #2 xx
	// TCCR0A = 0b0000.00x0; #1 WGM01 Waveform Generation Mode
	// TCCR0A = 0b0000.000x; #0 WGM00 Waveform Generation Mode
	TCCR0A |= (1 << COM0A1);
	TCCR0A &=~ (1 << COM0A0);
	TCCR0A &=~(1 << COM0B1);
	TCCR0A &=~ (1 << COM0B0);
	TCCR0A |= (1 << WGM01);
	TCCR0A |= (1 << WGM00);

	// TCCR0B = 0bx000.0000; #7 FOC0A Force Output Compare A
	// TCCR0B = 0b0x00.0000; #6 FOC0B Force Output Compare B
	// TCCR0B = 0b00x0.0000; #5 xx
	// TCCR0B = 0b000x.0000; #4 xx
	// TCCR0B = 0b0000.x000; #3 WGM02 Waveform Generation Mode + COM0A1 + COM0A0
	// TCCR0B = 0b0000.0x00; #2 CS02 Clock Select
	// TCCR0B = 0b0000.00x0; #1 CS01 Clock Select
	// TCCR0B = 0b0000.000x; #0 CS00 Clock Select
	TCCR0B &=~ (1 << FOC0A);
	TCCR0B &=~ (1 << FOC0B);
	TCCR0B &=~ (1 << WGM02);

	// TIMSK0 = 0b0000.0000; #7 xx
	// TIMSK0 = 0b0000.0000; #6 xx
	// TIMSK0 = 0b0000.0000; #5 xx
	// TIMSK0 = 0b0000.0000; #4 xx
	// TIMSK0 = 0b0000.0000; #3 OCIE0B Timer/Counter0 Output Compare Match B Interrupt
	// TIMSK0 = 0b0000.0000; #2 OCIE0A Timer/Counter0 Output Compare Match A Interrupt
	// TIMSK0 = 0b0000.0000; #1 TOIE0  Timer/Counter0 Overflow Interrupt Enable
	// TIMSK0 = 0b0000.0000; #0 xx
	TIMSK0 &=~ (1 << OCIE0B);
	TIMSK0 &=~ (1 << OCIE0A);
	TIMSK0 &=~ (1 << TOIE0);

	// TIFR0 = 0b0000.0000; #7 xx
	// TIFR0 = 0b0000.0000; #6 xx
	// TIFR0 = 0b0000.0000; #5 xx
	// TIFR0 = 0b0000.0000; #4 xx
	// TIFR0 = 0b0000.0000; #3 OCF0B Timer/Counter0 Output Compare B Match Flag
	// TIFR0 = 0b0000.0000; #2 OCF0A Timer/Counter0 Output Compare A Match Flag
	// TIFR0 = 0b0000.0000; #1 TOV0  Timer/Counter0 Overflow Flag
	// TIFR0 = 0b0000.0000; #0 xx
	TIFR0 &=~ (1 << OCF0B);
	TIFR0 &=~ (1 << OCF0A);
	TIFR0 &=~ (1 << TOV0);

	// GTCCR = 0b0000.0000; #7 TSM Timer/Counter Synchronization Mode
	// GTCCR = 0b0000.0000; #6 xx
	// GTCCR = 0b0000.0000; #5 xx
	// GTCCR = 0b0000.0000; #4 xx
	// GTCCR = 0b0000.0000; #3 xx
	// GTCCR = 0b0000.0000; #2 xx
	// GTCCR = 0b0000.0000; #1 xx
	// GTCCR = 0b0000.0000; #0 PSR10 Prescaler Reset Timer0/Counter
	GTCCR &=~ (1 << TSM);
	GTCCR &=~ (1 << PSR10);

	// TCNT0[7:0] ; # Timer0/Counter Register
	// OCR0A[7:0] ; # Output Compare Register A
	// OCR0B[7:0] ; # Output Compare Register B
	// TCNT0 = 0;
	OCR0A = 0;
	OCR0B = 128;
	}


void timer_set_clk(uint8_t a)
	{
		switch(a){
		case 0: { // Timer aus
			TCCR0B &=~ (1 << CS02);
			TCCR0B &=~ (1 << CS01);
			TCCR0B &=~ (1 << CS00);
			break;
			}
		case 1: { // Timer Clock 1:1
			TCCR0B &=~ (1 << CS02);
			TCCR0B &=~ (1 << CS01);
			TCCR0B |= (1 <<  CS00);
			break;
			}
		case 2: { // Timer Clock 1:8
			TCCR0B &=~ (1 << CS02);
			TCCR0B |=  (1 << CS01);
			TCCR0B &=~ (1 << CS00);
			break;
			}
		case 3: { // Timer Clock 1:64
			TCCR0B &=~ (1 << CS02);
			TCCR0B |=  (1 << CS01);
			TCCR0B |=  (1 << CS00);
			break;
			}

		case 4: { // Timer Clock 1:256
			TCCR0B |=  (1 << CS02);
			TCCR0B &=~ (1 << CS01);
			TCCR0B &=~ (1 << CS00);
			break;
			}

		case 5: { // Timer Clock 1:1024
			TCCR0B |=  (1 << CS02);
			TCCR0B &=~ (1 << CS01);
			TCCR0B |=  (1 << CS00);
			break;
			}

		case 6: { // Timer Clock external falling edge
			TCCR0B |=  (1 << CS02);
			TCCR0B |=  (1 << CS01);
			TCCR0B &=~ (1 << CS00);
			break;
			}

		case 7: { // Timer Clock external rising edge
			TCCR0B |=  (1 << CS02);
			TCCR0B |=  (1 << CS01);
			TCCR0B |=  (1 << CS00);
			break;
			}
		default:{ // default : Timer aus
			TCCR0B &=~ (1 << CS02);
			TCCR0B &=~ (1 << CS01);
			TCCR0B &=~ (1 << CS00);
			}
		}
	}

